Module gitai

Module gitai 

Structs

GitAiAuthorshipLog
A parsed git-ai authorship log.
GitAiFileEntry
Per-file entry from attestation section.

Functions

gitai_to_attribution
Convert a git-ai authorship log to tracevault’s Attribution format. diff_files provides the full diff so we can identify human-written lines (lines added in the diff but not listed in the git-ai note).
parse_gitai_note
Parse a git-ai note (from git notes --ref refs/notes/ai show <sha>).