Structs
- GitAi
Authorship Log - A parsed git-ai authorship log.
- GitAi
File Entry - Per-file entry from attestation section.
Functions
- gitai_
to_ attribution - Convert a git-ai authorship log to tracevault’s Attribution format.
diff_filesprovides the full diff so we can identify human-written lines (lines added in the diff but not listed in the git-ai note). - parse_
gitai_ note - Parse a git-ai note (from
git notes --ref refs/notes/ai show <sha>).